#!/bin/sh
PATH=/bin:/usr/bin:/usr/sbin:/fabos/bin:/fabos/link_bin:

ssavecomm="/fabos/cliexec/ssave_util.sh"

#
#include ssave utility
#
if [ -e "$ssavecomm" ]
then
    . $ssavecomm
    rc=$?
    if [ $rc -ne 0 ]
    then
      echo "Error -- $ssavecomm err=$rc"
    fi
else
    echo "Error -- could not locate $ssavecomm"
    exit 3
fi

##################################
# NAME
#    getUserPortList - Output the slist of user ports for a given slot
#
# SYNOPSIS
#    getUserPortList <slot_no> [ -list ]
#
# DESCRIPTION
#    This function parses the output of the diagshow command to extract the
#    list of user ports for the given slot.
#
# OPERANDS
#    NONE
##################################
getUserPortList()
{
  _initial_slot=$FABOS_SLOTNO
  export FABOS_SLOTNO=$1
  _cmd="/fabos/cliexec/exec_diag"
  _abc=""
  prev_port=""

  USER_PORT_LIST=${USER_PORT_LIST:-$($_cmd diagshow -use_bports 1 | \
 sed -n '/^[ \t]*--[ \t]/d;/ OK/s/^[ \t]*\([^ \t]*\).*/\1/p' )}

  if [ "$USER_PORT_LIST" != "" ]
  then
    USER_PORT_LIST=`/bin/echo $USER_PORT_LIST | \
       tr " " "\012" | \
       /usr/bin/cut -d"/" -f2 | \
       /bin/sort -n | \
       /usr/bin/xargs /bin/echo`
  else
      /bin/echo "NO_USER_PORTS"
      export FABOS_SLOTNO=$_initial_slot
      return
  fi
  if [ "$2" = "-list" ]
  then
    /bin/echo $USER_PORT_LIST
    return
  fi
  for port in $USER_PORT_LIST
  do
    if [ -z "$prev_port" ]
    then
      prev_port=$port
      last_port=$port
      first_port=$port
    else
      prev_port=`/usr/bin/expr $prev_port + 1`
      if [ $prev_port = $port ]
      then
        last_port=$port
      else
        # non-consecutive number, need to dump what we have so far
        if [ $first_port = $last_port ]
        then
          _abc="${_abc}${first_port},"
        else
       if { [ "$first_port" -lt "16" ] && [ "$last_port" -gt "15" ]  && [ "$2" = "-split" ]; }
       then
            _abc="${_abc}${first_port}-15,16-${last_port},"
       else
            _abc="${_abc}${first_port}-${last_port},"
           fi
        fi

        first_port=$port
        last_port=$port
    prev_port=$port
      fi
    fi
  done
  if [ -z "$_abc" ]
  then
    if [ -z "$first_port" ]
    then
      /bin/echo "NO_USER_PORTS"
      export FABOS_SLOTNO=$_initial_slot
      return
    else
      if [ $first_port != $last_port ]
      then
    if { [ "$first_port" -lt "16" ] && [ "$last_port" -gt "15" ]  && [ "$2" = "-split" ]; }
    then
           _abc=${first_port}-15,16-${last_port}
    else
       _abc=${first_port}-${last_port}
    fi
      else
    _abc=${first_port}
      fi
    fi
  else
    if [ $first_port != $last_port ]
    then
      if { [ "$first_port" -lt "16" ] && [ "$last_port" -gt "15" ]  && [ "$2" = "-split" ]; }
      then
           _abc=${_abc}${first_port}-15,16-${last_port}
      else
           _abc=${_abc}${first_port}-${last_port}
      fi
    else
      _abc=${_abc}${first_port}
    fi
  fi
  export FABOS_SLOTNO=$_initial_slot
  /bin/echo "$1/$_abc"
}

#
# helper for dumping fabric info per port
#
start_fab_port_cmd()
{
  #
  #display info by port #port
  #
  if [ "$slot" = "" ]
  then
    slot=0
  fi
  if [ "$multiBlade" = "TRUE" ]
  then
    str=$slot
  else
    str=""
  fi
  user_ports=`getUserPortList $slot -list`
  if [ "$user_ports" != "NO_USER_PORTS" ]
  then
    num_ports=`/bin/echo $user_ports | \
          /usr/bin/wc -w | \
          /usr/bin/tr -s " " " " | \
          /usr/bin/cut -d" " -f2`
    begport=`/bin/echo $user_ports | /usr/bin/cut -d" " -f 1`
    endport=`/bin/echo $user_ports | /usr/bin/cut -d" " -f $num_ports`
    for port in $user_ports
    do
        if [ $port -lt $begport ] || [ $port -gt $endport ]
        then
            continue
        fi
    #
    # for each port, fabric info
    #
    /bin/echo "fabportshow $str $port:"
    $CHASSISCMD /fabos/cliexec/fabportshow --slot $slot $port
    /bin/echo ""
    done
  else
    return
  fi
}

start_fcservice_internal()
{
  # don't dump this information on standby cp
  if [ "$STANDBY" = "TRUE" ]
  then
    return
  fi

  $SWITCHCMD /fabos/cliexec/fabricshow

  $SWITCHCMD /fabos/cliexec/dom

  $SWITCHCMD /fabos/cliexec/islshow

  #
  # Run following LF CLI's only if VF mode is ON.
  #
  if [ "$HOME_VF" != "" ]; then
    $CHASSISCMD lfcfg --showall -cfg

    $CHASSISCMD lfcfg --showall -lisl -v

    $CHASSISCMD lfmlog --dump
  fi

  $SWITCHCMD /fabos/cliexec/trunkshow

  #fabriclog --show()
  $SWITCHCMD /fabos/bin/fabriclog --show

  #fabswitchshow()
  $SWITCHCMD /fabos/cliexec/fabswitchshow

  #ess show
  $SWITCHCMD /fabos/bin/ess show

  #ess show
  $SWITCHCMD /fabos/bin/ess show dcl

  #fabstatsshow()
  $SWITCHCMD /fabos/cliexec/fabstatsshow

  # need to loop over slots and ports for this
  /bin/echo "fabportshow:"
 if [ "$multiBlade" = "TRUE" ] && [ "${all_slots-}" != "" ]
  then
    for a_slot in $all_slots
    do
      slot=$a_slot
      start_fab_port_cmd
    done
  else
    start_fab_port_cmd
  fi
  if [ "${internal_port}" != "" ]
  then
    $SWITCHCMD /fabos/cliexec/fabportshow $internal_port
  fi

  # uroutedump (not in 4.1, only 3.1)
  ###/bin/echo "uroutedump:"
  ###$CHASSISCMD uroutedump
  ###/bin/echo ""

  # 9. fspfShow()
  $SWITCHCMD /fabos/cliexec/fspfshow

  # fcplogshow() (not in 3.1)
  #$SWITCHCMD /fabos/cliexec/fcplogshow

  # Dumps zoning state-machine
  $SWITCHCMD /fabos/cliexec/zone stateshow

  # portzoneshow
  $SWITCHCMD /fabos/cliexec/portzoneshow

  # portcamshow
  # NOS6.0.1 (Defect 555528) - Comment out since hardzoning is not
  #   used in NOS. No need to unnecessarily use CPU cycles.
  #$SWITCHCMD /fabos/cliexec/portcamshow

  $SWITCHCMD /fabos/cliexec/cfgsize

  if [ "$HOME_VF" == "" ]; then
    #cfgsize show in AD 255 context
    /bin/echo "cfgsize output in AD255 context to reflect ALL zone DB info"
    $SWITCHCMD /fabos/link_abin/ad --exec 255 "cfgsize"
  fi

  $SWITCHCMD /fabos/cliexec/cfgshow

  $SWITCHCMD /fabos/cliexec/cfgtransshow

  if [ "$HOME_VF" == "" ]; then
    $CHASSISCMD /fabos/link_abin/ad --show

    #ad --validate
    $CHASSISCMD /fabos/link_abin/ad --exec 255 "/fabos/link_abin/ad --validate"

    #zone --validate
    $CHASSISCMD /fabos/link_abin/ad --exec 255 "zone --validate"
  fi

  $SWITCHCMD /fabos/link_abin/defzone --show

  $SWITCHCMD /fabos/link_bin/zone --show

   # msfr --showcfg
   $SWITCHCMD /fabos/link_abin/msfr --showcfg

  # bcastshow
  $SWITCHCMD /fabos/cliexec/bcastshow

  # rcssmshow
  $SWITCHCMD /fabos/cliexec/rcssmshow

  # rcsinfoshow
  $SWITCHCMD /fabos/cliexec/rcsinfoshow

  # rcsregistryshow
  $SWITCHCMD /fabos/cliexec/rcsregistryshow

  # zone mergeshow
  $SWITCHCMD /fabos/cliexec/zone mergeshow

  #ipfilter --show
  $CHASSISCMD /fabos/link_abin/ipfilter --show

  #iptables -L
  $CHASSISCMD /sbin/iptables -L

   /bin/echo "1.role:$ROLE_ID"
    export ROLE_ID=root
   /bin/echo "2.role:$ROLE_ID"
   /bin/echo "1login:$LOGIN_ID"
    export LOGIN_ID=root
   /bin/echo "2.login:$LOGIN_ID"

#ip6tables -L
  $CHASSISCMD /sbin/ip6tables -L

# porttrunkarea show commands
  $SWITCHCMD /fabos/link_sbin/porttrunkarea --show enabled

  $SWITCHCMD /fabos/link_sbin/porttrunkarea --show disabled

  $SWITCHCMD /fabos/link_sbin/porttrunkarea --show all

  $SWITCHCMD /fabos/link_sbin/porttrunkarea --show trunk

  $SWITCHCMD /fabos/cliexec/fcplogshow

# wwnaddress show command
  $SWITCHCMD /fabos/link_sbin/wwnaddress --show

  $SWITCHCMD /fabos/cliexec/topologyshow -1

  $SWITCHCMD /fabos/cliexec/fab_vcs mct_state

  $SWITCHCMD /fabos/cliexec/fab_vcs mct_counters

  $SWITCHCMD /fabos/cliexec/fab_vcs fcs_state

  $SWITCHCMD /fabos/cliexec/fab_vcs vrrp_state

  $SWITCHCMD /fabos/cliexec/fab_vcs mct_ha

  $SWITCHCMD /fabos/cliexec/fab_vcs fab_vcs_state

  $SWITCHCMD /fabos/cliexec/fab_vcs eth_ns_state

  $SWITCHCMD /fabos/cliexec/fab_vcs eth_ns_switch_show

  $SWITCHCMD /fabos/cliexec/fab_vcs eth_ns_stats_show

  $SWITCHCMD /fabos/cliexec/fab_vcs eth_ns_stats_show all

  $SWITCHCMD /fabos/cliexec/fab_vcs eth_ns_mq_stats

  $SWITCHCMD /fabos/cliexec/fab_vcs fab_stp_state

  $SWITCHCMD /fabos/cliexec/fab_vcs fab_stp_switch_show

  $SWITCHCMD /fabos/cliexec/fab_vcs fab_stp_mq_stats
  $SWITCHCMD /fabos/cliexec/fab_vxlan vxlan_state

  $SWITCHCMD /fabos/cliexec/fab_vxlan bfd_state

  $SWITCHCMD /fabos/cliexec/fab_vcs pgrp_state

  $SWITCHCMD /fabos/cliexec/fab_vcs hello_state

  $SWITCHCMD /fabos/cliexec/nsshow -r

  $SWITCHCMD /fabos/cliexec/nscamshow -t

  $SWITCHCMD /fabos/cliexec/nsallshow

  $SWITCHCMD /fabos/cliexec/nszonemember -a

  $SWITCHCMD /fabos/cliexec/ns portshow

  # fdmiShow - call this part of other services for now
  $SWITCHCMD /fabos/cliexec/fdmishow

  # fdmiCacheShow - with other fdmi
  $SWITCHCMD /fabos/cliexec/fdmicacheshow

  # nbrstateshow - Added in defect 41819
  $SWITCHCMD /fabos/cliexec/nbrstateshow

  $SWITCHCMD /fabos/cliexec/lsdbshow -1

  $SWITCHCMD /fabos/cliexec/interfaceshow -1

  $SWITCHCMD /fabos/cliexec/zone evlogshow

  $SWITCHCMD /fabos/cliexec/rcscmd logshow

  $SWITCHCMD /fabos/cliexec/ns allevlog

  $CHASSISCMD /fabos/bin/fspfstateshow

  $CHASSIS /fabos/cliexec/ms dump

  $SWITCHCMD /fabos/cliexec/rtstatsshow
}

# User FCSERVICE commands
start_fcservice_user()
{
	$CONFDCMD show fabric all
	$CONFDCMD show fabric isl
	$CONFDCMD show fabric islports
	$CONFDCMD show fabric route multicast
	$CONFDCMD show fabric route topology
	$CONFDCMD show fabric route linkinfo
	$CONFDCMD show fabric route neighbor-state
	$CONFDCMD show fabric trunk
	$CONFDCMD show fabric ecmp group
	$CONFDCMD show fibrechannel login
	$CONFDCMD show name-server detail
	$CONFDCMD show name-server brief

	$CONFDCMD show zoning operation-info

        # Added in Leo when enabled-configuration was moved out of DCMD distribution
	$CONFDCMD show zoning enabled-configuration

}


 for param in $@
  do
    if [ "$param" = "--user" ]
    then
      $EXEC_GROUP start_fcservice_user
    fi

    if [ "$param" = "--internal" ]
    then
        $EXEC_GROUP start_fcservice_internal
    fi

    exit $RETVAL
  done
