#!/bin/sh
#
#    Copyright (c) 1996-2011 Brocade Communications Systems, Inc.
#    All rights reserved.
#
#    File name:   ssave_infra.sh.in
#    Module name: utils/support
#
#    This file expected to be invoked by supportsave infrastructure to 
#    collect FOS/NOS infrastructure
#    related data for switch post fiaure analysis
#
#
PATH=/bin:/usr/bin:/usr/sbin:/fabos/bin:/fabos/link_bin:

ssaveutil="/fabos/cliexec/ssave_util.sh"

#
#include ssave utility
#
if [ -e "$ssaveutil" ]
then
    . $ssaveutil
    rc=$?
    if [ $rc -ne 0 ]
    then
      echo "Error -- $ssaveutil err=$rc"
      exit 3
    fi
else
    echo "Error -- could not locate ssave common library $ssaveutil"
    exit 3
fi
# *******************************************
# Collect cmsh data
# *******************************************
cmsh_cmd_exec()
{
    echo -e "*****************************************************************"
    echo -e "cmsh -e $@ :"
    echo -e "*****************************************************************"
    time /fabos/bin/cmsh -e "$@"
    echo -e "\n\n\n\n"
}

CMSHCMD=cmsh_cmd_exec

# *******************************************
# Collect IGMP data
# ******************************************
start_igmp()
{
 # Do not run on standby CP.
 if [ "$STANDBY" = "FALSE" ]
 then
    return
 fi
 /bin/echo "IGMP Commands:"
 /bin/date
 $CONFDCMD show ip igmp groups detail
 $CONFDCMD show ip igmp interface
 $CONFDCMD show ip igmp snooping
 $CONFDCMD show ip igmp snooping mrouter
 $CMSHCMD  "show ip igmp mcastss groups"
 $CMSHCMD  "show ip igmp remote info"
 $CMSHCMD  "sho ip igmp statistics"
 $CMSHCMD  "show debug igmp global"
 $CMSHCMD  "show debug igmp if"
 $CMSHCMD  "show debug igmp lag"
 $CMSHCMD  "show debug igmp pvlan"
 $CMSHCMD  "show debug igmp rbridge"
}


do_bladevershow() {
 # Do not run on standby CP.
 if [ "$STANDBY" = "TRUE" ]
 then
    return
 fi

 # If we are running on Saturn, get blade version for all AP blades.
 if [ $sw_platform == 42 ] || [ $sw_platform == 62 ] || [ $sw_platform == 77 ]
 then
    _cmd=`commandPath slotshow`
    ap1=`$_cmd | /bin/grep AP | wc -l`
    if [ $ap1 -gt 0 ]
    then
        for val in `$_cmd | /bin/grep AP | /bin/grep ENABLED | /usr/bin/cut -c1-5`
        do
            $CHASSISCMD bladevershow $val
        done
    /bin/echo ""
    fi
  else
    # Check if we are running on Sprint
    if [ $sw_platform = 46 ]  || [ $sw_platform = 95 ] || [ $sw_platform = 96 ] || [ $sw_platform = 97 ] || [ $sw_platform = 116 ] || [ $sw_platform = 107 ]
    then
       $CHASSISCMD bladevershow
    fi
  fi
}
# *******************************************
# Collect pre supportsave data
# *******************************************
start_pre()
{

    $ECHO "Platform: $sw_platform"
    $ECHO "Standby CP: $STANDBY"
    $ECHO "Line Card: $LC_PLATFORM"
    $ECHO "Confd Mode: $CONFDCLI"
    $ECHO "VF Mode: $VF_MODE"
    $ECHO "Date:"
    date

    # output ssave_util.sh log
    $CATFILE $ssutil_log

    # output previous supportsave log
    $CATFILE_RM /var/log/sslog.old

    # output previous suportsave ftp debug logs
    $ECHO "supportsave ftp debug log"
    $CATFILE_RM /var/log/ss_ftp_dbg_log

    # output supportsave error log /tmp/ss.log
    $ECHO "supportsave error log /tmp/ss.log"
    $CATFILE /tmp/ss.log
 
    if [ "$STANDBY" = "FALSE" ]
    then

	$CHASSISCMD /usr/bin/errlogutest -a2

	$CATFILE /tmp/errlogutestoutput.txt

	$CATFILE /proc/raslog/inq/hdr
	$CATFILE /proc/raslog/raslogd/hdr
	$CATFILE /proc/raslog/raslogd/msg
	$CATFILE /etc/raslog.conf

	if [ -e /usr/bin/errlogutest ] 
	then
	    /bin/rm /usr/bin/errlogutest
	fi
    fi

    # ouput console log
    if [ "$FABOS_OFF" = "FALSE" ]
    then
        $CHASSISCMD  /fabos/cliexec/catconsole /proc/consolelog

	$CHASSISCMD /fabos/cliexec/errdumpall
    fi
}

# *******************************************
# Collect RASLOG
# *******************************************
start_raslog()
{
	/bin/cat /etc/raslog.int /etc/raslog.ext /etc/raslog_dce.int /etc/raslog_dce.ext	
}

# *******************************************
# Collect INFRA User data
# *******************************************
start_infra_user()
{
    $CONFDCMD show vcs
    $CONFDCMD show vcs detail
    $CONFDCMD show logging raslog
    $CONFDCMD show logging audit 
    $CONFDCMD show support
    $CONFDCMD show version
    $CONFDCMD show firmwaredownloadstatus
	$CONFDCMD show firmwaredownloadstatus logical-chassis
    $CONFDCMD show firmwaredownloadhistory
    $CONFDCMD show process cpu
    $CONFDCMD show process cpu history
    $CONFDCMD show process cpu top
    $CONFDCMD show process memory
    $CONFDCMD show process info
    $CONFDCMD show chassis
    $CONFDCMD show environment fan
    $CONFDCMD show environment history
    $CONFDCMD show environment power
    $CONFDCMD show environment sensor
    $CONFDCMD show environment temp
	#$CONFDCMD show hardware-profile current
    $CONFDCMD show running-config
    $CONFDCMD show media
    $CONFDCMD show startup-config
    my_rbridge=`switchshow | grep -i rbridge | grep -iv trill | cut -d ":" -f2`
    $CONFDCMD show media optical-monitoring rbridge-id $my_rbridge
}

# *******************************************
# Collect CEE User data
# *******************************************
start_cee_user()
{
    $CONFDCMD show ip interface brief
    dmp_cnt=0
    while [ $dmp_cnt -lt 3 ]; do
         /bin/echo "Counter Dump iteration # $dmp_cnt:"
         /bin/echo ""
    $CONFDCMD show interface
         (( dmp_cnt += 1 ))
         sleep 1
    done

    $CONFDCMD show media 
    $CONFDCMD show port-channel detail
    $CONFDCMD show lacp counter
    $CONFDCMD show lacp sys-id
    $CONFDCMD show port-channel load-balance
    $CONFDCMD show vlan br
    $CONFDCMD show interface switchport
    $CONFDCMD show port-profile status
    $CONFDCMD show mac-address-table
    $CONFDCMD show port-profile interface all
    $CONFDCMD show sflow all
	$CONFDCMD show rmon
    $CONFDCMD show ipv6 mld groups
    $CONFDCMD show ipv6 mld snooping  mrouter
	$CONFDCMD show mcastss vlans
	$CONFDCMD show mcastss mrouter vlans
	$CONFDCMD show mcastss vlanmac
	$CONFDCMD show mcastss vlangrp
	$CONFDCMD show fabric ecmp load-balance

	$CONFDCMD show mac access-groups
	$CONFDCMD show dot1x all
	$CONFDCMD show cee maps
	$CONFDCMD show qos maps
	$CONFDCMD show qos interface all
	$CONFDCMD show qos queue interface all
	$CONFDCMD show qos flowcontrol interface all
	$CONFDCMD show qos rcv-queue interface all

	$CONFDCMD show spanning-tree brief
	$CONFDCMD show spanning-tree
	$CONFDCMD show spanning-tree mst
	$CONFDCMD show spanning-tree mst brief
	$CONFDCMD show spanning-tree mst detail
	$CONFDCMD show spanning-tree mst-config
	$CONFDCMD show spanning-tree pvst vlans
	$CONFDCMD show bpdu-drop

    $CONFDCMD show lldp
    $CONFDCMD show lldp neighbors detail
    $CONFDCMD show lldp statistics

    $CONFDCMD show vnetwork vcenter status
    $CONFDCMD show vnetwork dvpgs
    $CONFDCMD show vnetwork dvs
    $CONFDCMD show vnetwork hosts
    $CONFDCMD show vnetwork pgs
    $CONFDCMD show vnetwork vmpolicy macaddr
    $CONFDCMD show vnetwork vms
    $CONFDCMD show vnetwork vss
}

# *******************************************
# Collect INFRA Internal supportsave data
# *******************************************
start_infra_internal()
{
     /bin/echo "Date:"
     date
    /bin/echo""   /bin/echo""

#	$CHASSISCMD /sbin/hwclock

    if [ "$LC_PLATFORM" = "FALSE" ]
    then
     /bin/echo "Time Zone:"
     tstimezone
     /bin/echo""
     /bin/echo""
     /bin/echo "Version:"
     version
     /bin/echo""

    # ouput supportsave.conf
      $CATFILE /etc/fabos-private/supportsave-default.conf
    else
     $CATFILE /etc/fabos/supportsave.conf
    fi

    # Collect FFDC Trace OD files
    start_ffdc_trace_od

    # RAS-TRACE
    #output /proc/trace/ubuffers
    $CATPROC /proc/trace/ubuffers

    #output /proc/fabos/blade/*/info
    $CATPROC /proc/fabos/blade/*/info

    #output /proc/trace/kbuffers
    $CATPROC /proc/trace/kbuffers

    #output /proc/trace/tplist
    $CATPROC /proc/trace/tplist
	
    #Collect tracecfg
    $CATFILE /etc/fabos/trace.conf
    $CHASSISCMD /sbin/tracecfg -p

	# Collect tracecfg log file
	if [ -e "/var/log/tracecfg.log" ]
	then
     	$CATFILE /var/log/tracecfg.log 
	fi

    $CHASSISCMD coreshow -l

    $CATFILE /etc/syslog-ng/syslog-ng.conf

	#collect the dropq messages
	$CATPROC /proc/raslog/dropq/msg

    # HA
    # haDump
    $CHASSISCMD /fabos/cliexec/hadump

	# firmwarelog
	$CHASSISCMD /fabos/cliexec/firmwarelog

    # hasmtest dump
    $CHASSISCMD  /fabos/sbin/hasmtest dump 1

    # hasm.log
    $CATFILE /var/log/hasm.log

    # fsslo.log
    $CATFILE /var/log/fsslo.log

    # hadump.panic
    $CATFILE /var/log/hadump.panic

    # hasm.log.save
    $CATFILE /var/log/hasm.log.save

	# reboot log
	$CATFILE /var/log/reboot.log
	$CATFILE /var/log/reboot.log.save
	$CATFILE /mnt/var/log/reboot.log
	$CATFILE /mnt/var/log/reboot.log.save

    # dafd.log
    $CATFILE /var/log/dafd.log
    $CATFILE /mnt/var/log/dafd.log

    # FSSK_TH stack
    $CATFILE /proc/`ps -ef | /bin/grep FSSK_TH | /bin/grep -v grep | /bin/awk '{ print $2 }'`/stack

    # /var/log/messages files
    TRCFILES="`ls /var/log/messages*`"
    for f in $TRCFILES ; do
            $CATFILE $f
    done

    # MLT stats
    $ECHO "Dumping MLT (Memory Leak Tracking) Information - KMALLOC SIZE SORTED"
    $CHASSISCMD /bin/mlt -s 20
    for(( i = 1 ; i < 21; i++ )) 
    do
    	$CHASSISCMD /bin/mlt -d $i
    done

    $ECHO "Dumping MLT (Memory Leak Tracking) Information - KMALLOC COUNT SORTED"
    $CHASSISCMD /bin/mlt -t 20
    for(( i = 1 ; i < 21; i++ )) 
    do
    	$CHASSISCMD /bin/mlt -d $i
    done

    $ECHO "Dumping MLT (Memory Leak Tracking) Error Stats"
    $CATFILE /proc/mlt/stats

    # fsslo.log in secondary partition
    $CATFILE /mnt/var/log/fsslo.log

    # hasm.log in secondary partition
    $CATFILE /mnt/var/log/hasm.log

    $CATFILE /mnt/var/log/hasm.log.save

    # ISC
    $CATPROC /proc/isc/SWBD$SW_PLATFORM/sap

    $CATPROC /proc/isc/SWBD$SW_PLATFORM/epd

    $CATPROC /proc/isc/SWBD$SW_PLATFORM/dropped

	$CATPROC /proc/isc/sso

    $CATPROC /proc/hasm/ham

    $CHASSISCMD /sbin/chkconfig

if [ $SW_PLATFORM == 1000 ] || [ $SW_PLATFORM == 1001 ] 
then
    #proc voq_mode
    $CATPROC /proc/fabos/chassis/0/voq_mode

    #proc switch_port_map
    $CATPROC /proc/fabos/chassis/0/switch_port_map

    #proc slot_port_map
    $CATPROC /proc/fabos/chassis/0/slot_port_map
fi
    # backend links for mercury chassis
    # FPGA contents
    if [ $SW_PLATFORM == 1000 ] || [ $SW_PLATFORM == 1001 ] || \
	[ $SW_PLATFORM == 1002 ] || [ $SW_PLATFORM == 1003 ]
    then
	$CATPROC /proc/tgec0/port_status
	$CATPROC /proc/cp*/fpga
    fi
    if [ $SW_PLATFORM == 1004 ] || [ $SW_PLATFORM == 1005 ] || \
        [ $SW_PLATFORM == 1009 ] || [ $SW_PLATFORM == 1010 ] || \
	[ $SW_PLATFORM == 1011 ]
    then
	$CATPROC /proc/tsec2/port_status
	$CATPROC /proc/system/fpga
    fi

    # Dump Gearbox proc entries 1-6 for 6x100G blade
    if [ $SW_PLATFORM == "1009" ]
    then
        $CATPROC /proc/fabos/blade/*/Gearbox_*
    fi

	if [ $sw_platform == 123 ] || [ $sw_platform == 112 ]
	then
		$CATPROC /proc/system/fpga
	fi

    #MI/MI6
    $CATPROC /proc/mi/*

    # HAML
    $CATPROC /proc/haml/pending_messages
    $CATPROC /proc/haml/stats

    if [ "$LC_PLATFORM" = "FALSE" ]
    then
    $CHASSISCMD /fabos/cliexec/dbgshow

    # 2. uptime()
    # $CHASSISCMD /fabos/cliexec/uptime

    #portstatshow 
    switchshow | grep " FC " | awk '{print $1}'| while read line
    do 
	port=$(echo $line)
    $SWITCHCMD /fabos/cliexec/portstatsshow -1/$(($port+1))
    done


  # 12. historyshow()
  $CHASSISCMD /fabos/cliexec/historyshow
    fi

	$CATFILE /fabos/config/system-conf

	$CATFILE /var/log/inetdDebug.log

	$CATFILE /var/log/inetdDebug.log.1

	$CATFILE /mnt/var/log/inetdDebug.log

	$CATFILE /mnt/var/log/inetdDebug.log.1

	$CATFILE /var/log/fwdl.log

	$CATFILE /var/log/fwdl.log.save

	$CATFILE /mnt/var/log/fwdl.log

	$CATFILE /mnt/var/log/fwdl.log.save

	$CATFILE /tmp/pd_temp_errlog

	$CATFILE /etc/.pd_data

	#version.conf for MM and LC
	$CATFILE /etc/version.conf
	$CATFILE /mnt/etc/version.conf

    if [ "$LC_PLATFORM" = "FALSE" ]
    then
      # VF SWITCH CONFIGURATION
      # Switch configuraton switch-conf.xx, vf-conf.xx
      $CATFILE /fabos/config/vf-conf.$SW_PLATFORM
      $CATFILE /fabos/config/switch-conf.$SW_PLATFORM
      $CATFILE /fabos/config/vf-conf.$SW_PLATFORM.save
      $CATFILE /fabos/config/switch-conf.$SW_PLATFORM.save

      # Default switch configuration switch-conf, vf-conf, system-conf
      $CATFILE /fabos/config/vf-conf

      $CATFILE /fabos/config/switch-conf

	  # Firmware capablity bitmap Configuration
	  $CATFILE /fabos/config/cap-conf

      # let user know what login session was used
      $SWITCHCMD /fabos/sbin/myid
      _cmd=`commandPath slotshow`   

      $CHASSISCMD firmwareshow -v

      $CHASSISCMD firmwareshow -a

      $CHASSISCMD firmwaredownloadstatus

      if [ "$LC_PLATFORM" = "FALSE" ]
      then
	  $CHASSISCMD firmwareshow --history
      fi

      if [ "$STANDBY" = "FALSE" ]
      then

      # 3. switchShow()
      previous_ad=$CURRENT_AD
      export CURRENT_AD=0
      $SWITCHCMD /fabos/bin/switchshow
      CURRENT_AD=$previous_ad

      # 4. tempshow()
      $CHASSISCMD /fabos/cliexec/tempshow

      # 4b. sensorshow()
      $CHASSISCMD /fabos/cliexec/sensorshow

      # 5. psshow()
       $CHASSISCMD /fabos/cliexec/psshow

      # 6. fanshow()
       $CHASSISCMD /fabos/cliexec/fanshow

      # 8. portcfgshow
      $SWITCHCMD /fabos/cliexec/portcfgshow

     # 9. portErrShow()
	   #portErrshow takes a long time during supportsave.
	   #So, commenting it out.
      #$SWITCHCMD /fabos/cliexec/porterrshow

      $SWITCHCMD /fabos/cliexec/fwsamshow

      # 13. portswapshow()
      $CHASSISCMD /fabos/cliexec/portswapshow

      $CHASSISCMD /fabos/link_bin/fosconfig --show

      fi

      # 7a. licenseidshow
      $CHASSISCMD /fabos/cliexec/licenseidshow

      # 7b. licenseshow
      $CHASSISCMD /fabos/cliexec/licenseshow

      # 7c. licenseport --show
      $CHASSISCMD /fabos/link_sbin/licenseport --show

 
      # 10. slotshow()

      if [ "$multiBlade" = "TRUE" ]
      then
        $CHASSISCMD /fabos/cliexec/slotshow -m
      fi
      # with the 576 option, it works for all machines
      # and includes all FRU's in inventory
      $CHASSISCMD /fabos/cliexec/slotshow -d576

      $CHASSISCMD /fabos/cliexec/emtraceshow

      $CHASSISCMD /fabos/cliexec/emtraceshow2

      $CHASSISCMD /fabos/cliexec/emhsmtraceshow

      $CHASSISCMD /fabos/cliexec/systraceshow -d

      # 11. chassisshow()
      $CHASSISCMD /fabos/cliexec/chassisshow

      # $CHASSISCMD timeout


  # 14. do_bladevershow()
   do_bladevershow

   # 15. switch-conf.xx
      $CATFILE /fabos/config/switch-conf.$sw_platform

   # 16. switch-conf default
      $CATFILE /fabos/config/switch-conf

  # 17. Chassis E2E show
  if [ $sw_platform == 1000 ] || [ $sw_platform == 1001 ] ||
	 [ $sw_platform == 1002 ] || [ $sw_platform == 1003 ]; then
	  $CHASSISCMD /fabos/sbin/dbc chassis e2e show all
  fi

  # 18. IGMP commands
	start_igmp
  # 18. profiledump
	#$CHASSISCMD  /fabos/bin/profiledump

  # last configshow
      # cause segement fault 7/15/2011
      #$CHASSISCMD /fabos/cliexec/configshow -all | /bin/cat # the cat at end of pipe avoids more's paging

      $CATFILE /var/log/copy_cmd_error
  fi
}

# *******************************************
# Collect FOS config
# *******************************************
start_infra_foscfg()
{
	$CHASSISCMD /fabos/cliexec/configshow -all | /bin/cat # the cat at end of pipe avoids more's paging

	$CATFILE /var/log/config_updown.log

	$CATFILE /var/log/config_updown.log.save

	$CATFILE /mnt/var/log/config_updown.log

	$CATFILE /mnt/var/log/config_updown.log.save

	#the below get executed only if configshow fails
	#cat chassis section of config file
	temp=`/bin/ls /tmp/config_chassis*`
	for file in $temp
	do
		$CATFILE $file
	done

	#cat default switch section of config file
	temp=`/bin/ls /tmp/sw*`
	for file in $temp
	do
		$CATFILE $file
	done
}


SET_OD="/bin/ln -s /fabos/cliexec/errlogtest /fabos/sbin/rasod"
UNSET_OD="/bin/rm -f /fabos/sbin/rasod"
FILE_SIZE_50M=52428800

# *******************************************
# Collect Objectdump
# *******************************************
start_ffdc_trace_od()
{
	Date=`date +%Y%m%d%H%M`
	$CHASSISCMD /fabos/sbin/rasod -d -w-2 -m3 -y4 -t 180 -o /var/trace/tracess.$Date.trc.od
	# The first trace dump is very stable, no longer need the second tracedump
	#$CHASSISCMD /fabos/sbin/rasod -d -w-2 -m3 -y4 -t 180 -o /var/trace/tracesecondss.$Date.trc.od

	if [ ! -e "/var/trace/trace_id.dat" ]
	then
		echo "File: /var/trace/trace_id.dat not found"
		$CHASSISCMD /fabos/sbin/tracedbadd -e
	fi
	

	nfile=`ls -l /var/trace/* | wc -l`
	mnt_nfile=`ls -l /mnt/var/trace/* | wc -l`
	if [ "$mnt_nfile" -eq 0 ]
	then
		$ECHO "No trace FFDC OD found " > /mnt/var/trace/ffdc_trace_od
	fi

	if [ "$nfile" -eq 0 ]
	then
		$ECHO "No trace FFDC OD found " > /var/trace/ffdc_trace_od
		$CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/ffdc_trace_od /mnt/var/trace/*
		/bin/rm -f /var/trace/ffdc_trace_od 
		/bin/rm -f /mnt/var/trace/*.od
		/bin/rm -f /mnt/var/trace/ffdc_trace_od
	else
		free_space=`/bin/df --block-size=1 /| grep -v Filesystem | awk '{print $4}'`
		estmate_tarfilesize=`tar -czf - /var/trace/* /mnt/var/trace/* | wc -c 2> /dev/null`
		min_size=`/usr/bin/expr $free_space - $FILE_SIZE_50M`

		# In the case of not enough CF, need to collect tracess.xxxxx.xx file
		if [ $free_space -lt $estmate_tarfilesize]
		then
			$CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracess* /var/trace/*.dat
			/fabos/cliexec/errlogtest -i TRCE-5022 -a $Date
			return;
		fi

		#tar tracepd & traces only if estimate tar > freespace-50MB
		if [ $estmate_tarfilesize -gt $min_size ]
		then
			$CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracess* /var/trace/*.dat
			pdfile=`ls -l /var/trace/tracepd* | wc -l`
			if [ $pdfile -ge 1 ] ;then
				$CHASSISCMD tar -rvf /var/log/TRACE_FFDC_OD.tar /var/trace/tracepd*
			fi
			/bin/rm /var/trace/*.od
			/bin/rm /var/trace/tracepd*
			/fabos/cliexec/errlogtest -i TRCE-5022 -a $Date
		else
			$CHASSISCMD tar -cvf /var/log/TRACE_FFDC_OD.tar /var/trace/* /var/smrtdc/* /mnt/var/trace/*
			/bin/rm -f /var/trace/*.od
			/bin/rm -f /mnt/var/trace/*.od
			/bin/rm -f /mnt/var/trace/ffdc_trace_od
			/bin/rm -f /var/smrtdc/*
			/bin/rm -f /var/trace/tracepd*
		fi
	fi
}

# *******************************************
# Collect post supportsave data
# *******************************************
start_post()
{     
    if [ "$FABOS_OFF" = "FALSE" ]
    then
      $CHASSISCMD  /fabos/cliexec/catconsole /proc/consolelog
      $CHASSISCMD /fabos/cliexec/errdumpall
    fi

    # output supportsave log
    $CATFILE /var/log/sslog

    # output previous suportsave ftp debug logs
    $ECHO "supportsave ftp debug log"
    $CATFILE_RM /var/log/ss_ftp_dbg_log

    # output supportsave error log /tmp/ss.log
    $ECHO "supportsave error log /tmp/ss.log"
    $CATFILE /tmp/ss.log

    $CATFILE_RM /var/log/assert.log

    # Print /tmp/messages in oldest to latest order.
    for file_no in [2 1]
      do
	$CATFILE /var/log/messages.$file_no
      done

    $CATFILE /var/log/messages

    # output ssutil CLI log 
    $CATFILE_RM $ssutil_log

    # output supportsave error log /tmp/ss.log
    $CATFILE /var/log/ss_module_log

   #$ECHO "CPU 100% due to low memory : 000530131 - recovery workaround"
   $CHASSISCMD echo 10240 > /proc/sys/vm/min_free_kbytes
   $CHASSISCMD sysctl -q -p /etc/sysctl.conf

}

#silicond support
silicond_dump ()
{
		PID= ps ax | grep silicond | awk '{print $1}'
		kill -10 $PID
}
# To handle multiple params
# for param in $@
#  do
#    if [ "$param" = "--of" ]
#    then
#      outf_enable=1	 
#    fi
#  done

#Adding support for silicond stats
# silicond_dump	
 for param in $@
  do
    if [ "$param" = "--pre" ]
    then
      $EXEC_GROUP start_pre
    fi

    if [ "$param" = "--raslog" ]
    then
      start_raslog
    fi

	if [ "$param" = "--internal" ]
	then
		$EXEC_GROUP start_infra_internal
	fi

    if [ "$param" = "--user" ]
    then
      $EXEC_GROUP start_infra_user
    fi

    if [ "$param" = "--ceeuser" ]
    then
        $EXEC_GROUP start_cee_user 
    fi
	
	if [ "$param" = "--foscfg" ]
	then
		$EXEC_GROUP start_infra_foscfg
	fi

    if [ "$param" = "--post" ]
     then
     $EXEC_GROUP start_post
    fi
    exit $RETVAL
  done

