#!/bin/sh
PATH=/bin:/usr/bin:/usr/sbin:/fabos/bin:/fabos/link_bin:

ssavecomm="/fabos/cliexec/ssave_util.sh"

#
#include ssave utility
#
if [ -e "$ssavecomm" ]
then
    . $ssavecomm
else
    echo "Error -- could not locate $ssavecomm"
    exit 3
fi

start_os()
{
  #tr did not like the spaces
  #export TERMINFO=/usr/share/terminfo
  $CHASSISCMD printenv
  $CHASSISCMD /usr/bin/w
  $CHASSISCMD /usr/bin/vmstat
  #$CHASSISCMD /usr/bin/top -n1
  $CHASSISCMD /usr/bin/iostat
  $CHASSISCMD /sbin/mii-tool -vvv
  $CHASSISCMD /bin/df -h
  $CHASSISCMD /usr/bin/du -xh /
  /bin/echo "********************************************************"
  /bin/echo "        Top Ten Most Disk Consuming Files         "
  /bin/echo "********************************************************"
  /usr/bin/find / -fstype nfs -prune -o -path /mnt -prune -o -printf '%s %p\n'|sort -nr|head
  /bin/echo "********************************************************"

  # list /var/log dir
  $CHASSISCMD /bin/ls -l /var/log
  $CHASSISCMD /bin/ls -l /tmp

  # had a request for -aux?
  $CHASSISCMD /bin/ps exfcl

  $CHASSISCMD /bin/rpm -qa

  # Why not use the dmesg command, cause the log is overwritten by other kernel
  # modules. /var/log/dmesg preserve dmesg info during the boot up.
  $CATFILE /var/log/dmesg

  $CHASSISCMD /bin/dmesg

  $CATFILE /etc/fstab

  $CATFILE /etc/mtab

  $CATFILE /proc/sys/kernel/printk
  
  $CATFILE /proc/net/tcp6

  $CATFILE /sys/block/sda/stat

  $CATFILE /proc/diskstats

  $CHASSISCMD /usr/bin/iostat -xk

  # linux proc
  proc_entries="buddyinfo,cmdline,cpuinfo,crypto,devices,diskstats,filesystems,interrupts,iomem,ioports,loadavg,locks,meminfo,misc,modules,mounts,mtd,net/tcp,net/udp,net/netstat,net/sockstat,panicdump,partitions,pci,pdmisc,sched_debug,slabinfo,softirqs,stat,tty/drivers,uptime,version,vmallocinfo,zoneinfo*/fpga,ddr_ecc/ecc_stats"

  for proc_entry in `/bin/echo $proc_entries | /usr/bin/tr "," "\n"`
  do
    $CATFILE /proc/$proc_entry
  done

  $CHASSISCMD /usr/bin/find /core_files /mnt/core_files -type f

  if [ "$FABOS_OFF" = "FALSE" ]
  then
    # fabos proc
    proc_entries="iu/stats,switch/*/logical_info"
    for proc_entry in `/bin/echo $proc_entries | /usr/bin/tr "," "\n"`
    do
      $CATFILE /proc/fabos/$proc_entry
    done
  fi

  if [ "$SSAVE" = "FALSE" ]
  then
    /bin/echo "validating rpm database on primary partition"
    $CHASSISCMD /bin/rpm -Va
  fi

  # icmp and tcp burstrate
  $CATFILE /proc/sys/net/ipv4/conf/eth0/ip_unreachable
  $CATFILE /proc/sys/net/ipv4/conf/eth0/icmp_echo_ignore
  $CATFILE /proc/sys/net/ipv4/conf/eth0/icmp_rlimit_enable
  $CATFILE /proc/sys/net/ipv4/icmp_ratemask
  $CATFILE /proc/sys/net/ipv6/conf/eth0/ipv6_unreach
  $CATFILE /proc/sys/net/ipv6/conf/eth0/echo_ignore
  $CATFILE /proc/sys/net/ipv6/icmp/ratelimit
  $CATFILE /proc/sys/net/ipv4/tcp_rate_limit
  $CATFILE /proc/sys/net/ipv4/tcp_rate_limit_drop_time
  $CATFILE /proc/net/tcp_rate_limit_log
  $CATFILE /proc/net/netlink
  $CATFILE /etc/icmp.conf
  $CATFILE /etc/tcpburstrate.conf

  $CHASSISCMD /sbin/bootenv
  $CHASSISCMD /sbin/sin
  $CHASSISCMD /bin/df
  $CHASSISCMD /sbin/ifconfig
  $CHASSISCMD /sbin/route
  $CHASSISCMD /bin/hostname
  $CHASSISCMD cat /proc/net/arp
  $CHASSISCMD /sbin/ip -s link
  $CHASSISCMD /sbin/ip -s addr
  $CHASSISCMD /bin/netstat -an
  $CHASSISCMD /bin/netstat -ng
  $CATFILE /proc/vsd_info
  $CATFILE /proc/standby_console
  $CATFILE /proc/hv_console
  for memfile in `/bin/ls -tr /var/log/mstatdir/memorystatus*`
  do
    $CATFILE $memfile
  done

}

start_sar()
{
  /usr/local/lib/sa/sa2 -bBdqrRuvwy -I SUM -I XALL -n ALL -P ALL -u ALL
  if [ !  -d /var/log/sa ]; then
	/bin/mkdir /var/log/sa
  fi;
  cd /var/log/sa
  if [ ! -e sar* ]; then
       /bin/echo "No data present" > /var/log/sa/sarXX
  fi;

  $CHASSISCMD /bin/tar -cvf sar_report.tar sar* /var/log/ipadmd_log*

  cd -
  /bin/sync
  /bin/echo ""

        # Capture ipadmd_log* in SS
	/bin/echo "********************************************************"
	/bin/echo "        Ipadmd Information         "
	/bin/echo "********************************************************"

        nfile=`ls -l /var/log/ | grep ipadmd_log* | wc -l`
        if [ "$nfile" -eq 0 ]
        then
               $ECHO "No ipadmd_log* logs found"
        fi

        # Required Ipadmd infor similar to ipadm_ffdc.sh
        ipadmd_name="ipadmd"
        pids=`ps --no-headers --format pid -C ${ipadmd_name}`
        pidsnospaces=`echo "$pids" | tr -d \[\:blank\:\]`
        echo ${ipadmd_name} pids ${pidsnospaces}

        if [ -z "${pidsnospaces}" ]
        then
                $ECHO "No ipadmd pid found"
        else

        pid1=`expr match "$pidsnospaces" '\([0-9]*\)'`
        echo sending SIGUSR1 to ${pid1}
        /bin/kill -s USR1 ${pid1}
        sleep 3
        /bin/kill -s USR1 ${pid1}
        echo 'ls -al /tmp/ip*'
        /bin/ls -al /tmp/ip*
                if [ -r /tmp/ipadm_data.txt ]
                then
                        echo '/tmp/ipadm_data.txt'
                        cat /tmp/ipadm_data.txt
                else
                        echo '/tmp/ipadm_data.txt is absent'
                fi
        fi
	/bin/echo "  End Ipadmd Information ********************************"
	# End ipadmd 
}

$EXEC_GROUP start_os
$EXEC_GROUP start_sar

